==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/HYPERLINKURLPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour HYPERLINKURLPARAMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="HYPERLINKURLPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}URLPARAMETERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCREENHYPERLINKID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HYPERLINKURLPARAMETERID_Type", propOrder = {
    "urlparameterid",
    "screenhyperlinkid"
})
public class HYPERLINKURLPARAMETERID_Type {

    @XmlElement(name = "URLPARAMETERID", required = true)
    protected URLPARAMETERID_Type urlparameterid;
    @XmlElement(name = "SCREENHYPERLINKID", required = true)
    protected SCREENHYPERLINKID_Type screenhyperlinkid;

    /**
     * Obtient la valeur de la propriété urlparameterid.
     * 
     * @return
     *     possible object is
     *     {@link URLPARAMETERID_Type }
     *     
     */
    public URLPARAMETERID_Type getURLPARAMETERID() {
        return urlparameterid;
    }

    /**
     * Définit la valeur de la propriété urlparameterid.
     * 
     * @param value
     *     allowed object is
     *     {@link URLPARAMETERID_Type }
     *     
     */
    public void setURLPARAMETERID(URLPARAMETERID_Type value) {
        this.urlparameterid = value;
    }

    /**
     * Obtient la valeur de la propriété screenhyperlinkid.
     * 
     * @return
     *     possible object is
     *     {@link SCREENHYPERLINKID_Type }
     *     
     */
    public SCREENHYPERLINKID_Type getSCREENHYPERLINKID() {
        return screenhyperlinkid;
    }

    /**
     * Définit la valeur de la propriété screenhyperlinkid.
     * 
     * @param value
     *     allowed object is
     *     {@link SCREENHYPERLINKID_Type }
     *     
     */
    public void setSCREENHYPERLINKID(SCREENHYPERLINKID_Type value) {
        this.screenhyperlinkid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/HYPERLINKURLPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for HYPERLINKURLPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HYPERLINKURLPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}URLPARAMETERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCREENHYPERLINKID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HYPERLINKURLPARAMETERID_Type", propOrder = {
    "urlparameterid",
    "screenhyperlinkid"
})
public class HYPERLINKURLPARAMETERID_Type {

    @XmlElement(name = "URLPARAMETERID", required = true)
    protected URLPARAMETERID_Type urlparameterid;
    @XmlElement(name = "SCREENHYPERLINKID", required = true)
    protected SCREENHYPERLINKID_Type screenhyperlinkid;

    /**
     * Gets the value of the urlparameterid property.
     * 
     * @return
     *     possible object is
     *     {@link URLPARAMETERID_Type }
     *     
     */
    public URLPARAMETERID_Type getURLPARAMETERID() {
        return urlparameterid;
    }

    /**
     * Sets the value of the urlparameterid property.
     * 
     * @param value
     *     allowed object is
     *     {@link URLPARAMETERID_Type }
     *     
     */
    public void setURLPARAMETERID(URLPARAMETERID_Type value) {
        this.urlparameterid = value;
    }

    /**
     * Gets the value of the screenhyperlinkid property.
     * 
     * @return
     *     possible object is
     *     {@link SCREENHYPERLINKID_Type }
     *     
     */
    public SCREENHYPERLINKID_Type getSCREENHYPERLINKID() {
        return screenhyperlinkid;
    }

    /**
     * Sets the value of the screenhyperlinkid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SCREENHYPERLINKID_Type }
     *     
     */
    public void setSCREENHYPERLINKID(SCREENHYPERLINKID_Type value) {
        this.screenhyperlinkid = value;
    }

}
